/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.p4java.extension.server;

import com.perforce.p4java.extension.utility.Validate;

/**
 * Provides static methods to create {@code PrincipalCredential}s for
 * authentication against a Perforce server.
 */
public class PerforcePrincipalCredential implements PrincipalCredential {

    String principal;
    String credential;

    private PerforcePrincipalCredential(String principal, String credential) {
	this.principal = principal;
	this.credential = credential;
    }

    /**
     * Creates a {@code PrincipalCredential} based on String values for user
     * name and password.
     * 
     * @param principal
     *            the String user name of the Perforce user. Non-null.
     * @param credential
     *            the String password of the Perforce user. May be null or
     *            empty, if no password.
     * @return a PrincipalCredential for the provided user name and password.
     *         Never null.
     */
    public static PrincipalCredential createUser(String principal,
	    String credential) {
	Validate.notNull(principal,
		"principal must not be null to PerforcePrincipalCredential.createUser");
	if (credential == null)
	    credential = "";

	return new PerforcePrincipalCredential(principal, credential);
    }

    /**
     * @see com.perforce.p4java.extension.server.PrincipalCredential#getPrincipal()
     */
    public String getPrincipal() {
	return principal;
    }

    /**
     * @see com.perforce.p4java.extension.server.PrincipalCredential#getCredential()
     */
    public String getCredential() {
	return credential;
    }

    /**
     * @see com.perforce.p4java.extension.server.PrincipalCredential#isValid()
     */
    public boolean isValid() {
	return true;
    }

}
